==> haskell-hspec-core-2.11.4-4-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.11.4
visibility:           public
id:                   hspec-core-2.11.4-EJeSUBHzwmhKLMct0Rj4Af
key:                  hspec-core-2.11.4-EJeSUBHzwmhKLMct0Rj4Af
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  4b879ad5b904791172187fbba8600d81
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/hspec-core-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.11.4-EJeSUBHzwmhKLMct0Rj4Af
depends:
    HUnit-1.6.2.0-DUvlqmsw2Kp6tCDRl9WtXA
    QuickCheck-2.15.0.1-5wgMd498nCWIkHPGslLJlo
    ansi-terminal-1.0.2-HSq0v3QUl8T11Wgx1QLnTe array-0.5.4.0
    base-4.17.2.1 call-stack-0.4.0-AAQ0PbHtRxA9hkeprsdCAo
    deepseq-1.4.8.0 directory-1.3.7.1 filepath-1.4.2.2
    haskell-lexer-1.1.2-K4xn3msH1rqDmzpJS8M1s1
    hspec-expectations-0.8.4-8kbQPZh0Wgi2TqXq1qz92F process-1.6.18.0
    quickcheck-io-0.2.0-9VMgFh6sPJXJ5C8D5CMjH4
    random-1.2.1.3-KY8hXIsRO0nEsZvihu4hBT stm-2.5.1.0
    tf-random-0.5-5of6DWppTHeFaBLq7uTU4g time-1.12.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hspec-core-2.11.4-22-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-hspec-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hspec-core
version:              2.11.4
visibility:           public
id:                   hspec-core-2.11.4-3lTlb7BsKTGGhqQwbCqOww
key:                  hspec-core-2.11.4-3lTlb7BsKTGGhqQwbCqOww
license:              MIT
copyright:
    (c) 2011-2023 Simon Hengel,
    (c) 2011-2012 Trystan Spangler,
    (c) 2011 Greg Weber

maintainer:           Simon Hengel <sol@typeful.net>
stability:            experimental
homepage:             https://hspec.github.io/
synopsis:             A Testing Framework for Haskell
description:
    This package exposes internal types and functions that can be used to extend Hspec'\''s functionality.

category:             Testing
abi:                  542e6d0a458362103faef36f1f772ba2
exposed:              True
exposed-modules:
    Test.Hspec.Core.Format Test.Hspec.Core.Formatters
    Test.Hspec.Core.Formatters.V1 Test.Hspec.Core.Formatters.V2
    Test.Hspec.Core.Hooks Test.Hspec.Core.QuickCheck
    Test.Hspec.Core.Runner Test.Hspec.Core.Spec Test.Hspec.Core.Util

hidden-modules:
    GetOpt.Declarative GetOpt.Declarative.Environment
    GetOpt.Declarative.Interpret GetOpt.Declarative.Types
    GetOpt.Declarative.Util NonEmpty Test.Hspec.Core.Clock
    Test.Hspec.Core.Compat Test.Hspec.Core.Config
    Test.Hspec.Core.Config.Definition Test.Hspec.Core.Config.Options
    Test.Hspec.Core.Example Test.Hspec.Core.Example.Location
    Test.Hspec.Core.FailureReport Test.Hspec.Core.Formatters.Diff
    Test.Hspec.Core.Formatters.Internal
    Test.Hspec.Core.Formatters.Pretty
    Test.Hspec.Core.Formatters.Pretty.Parser
    Test.Hspec.Core.Formatters.Pretty.Parser.Parser
    Test.Hspec.Core.Formatters.Pretty.Unicode
    Test.Hspec.Core.Formatters.V1.Free
    Test.Hspec.Core.Formatters.V1.Internal
    Test.Hspec.Core.Formatters.V1.Monad Test.Hspec.Core.QuickCheckUtil
    Test.Hspec.Core.Runner.Eval Test.Hspec.Core.Runner.JobQueue
    Test.Hspec.Core.Runner.PrintSlowSpecItems
    Test.Hspec.Core.Runner.Result Test.Hspec.Core.Shuffle
    Test.Hspec.Core.Spec.Monad Test.Hspec.Core.Timer
    Test.Hspec.Core.Tree Control.Concurrent.Async Data.Algorithm.Diff
    Paths_hspec_core

import-dirs:          /usr/lib/ghc-9.6.7.20250817/site-local/hspec-core-2.11.4
library-dirs:         /usr/lib/ghc-9.6.7.20250817/site-local/hspec-core-2.11.4
library-dirs-static:  /usr/lib/ghc-9.6.7.20250817/site-local/hspec-core-2.11.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hspec-core
hs-libraries:         HShspec-core-2.11.4-3lTlb7BsKTGGhqQwbCqOww
depends:
    HUnit-1.6.2.0-a0sGYhVQliLTRPu3iH7Dr
    QuickCheck-2.15.0.1-EwaWMBElPTW2PPUquYLZSL
    ansi-terminal-1.1-DDTOncISchdDnKGquLYrQE array-0.5.8.0
    base-4.18.3.0 call-stack-0.4.0-D3kOb1gXhq8E84SgXdsTIH
    deepseq-1.4.8.1 directory-1.3.8.5 filepath-1.4.301.0
    haskell-lexer-1.2-KCpibEfPPf7Gyfnzanypqa
    hspec-expectations-0.8.4-9gZQ2G6q3JkFXqyTwrYkjr process-1.6.19.0
    quickcheck-io-0.2.0-KsxiIPAYPRJJm76z34ldIh
    random-1.2.1.3-FQDOWOOVQ4iCxkTbz7wiP5 stm-2.5.1.0
    tf-random-0.5-kEfbXrbIPPEFj8u3xjnPy time-1.12.2
    transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-hspec-core/html/hspec-core.haddock
haddock-html:         /usr/share/doc/haskell-hspec-core/html
' | '/usr/bin/ghc-pkg-9.6.7.20250817' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
